@@ -3,7 +3,7 @@ Module for visualizing the tree for a whole sps-calculation
 """
 from spinterface.sps_results.stage_visualizer.ivisstage import IVisStage
 from pathlib import Path
-from typing import Union
+from typing import Union, Dict
 from treelib import Node, Tree
 import ete3 as et
 import pandas as pd
@@ -17,7 +17,8 @@ class CVisTree(IVisStage):
     """
 
     def __init__(self, strategy: int, info_file_disp: Union[Path, str], info_file_esc: Union[Path, str],
-                 info_file_conv: Union[Path, str]) -> None:
+                 info_file_conv: Union[Path, str],
+                 stage_strategies: Dict[str, int] = {'DISP': 2, 'ESC': 1, 'CONV': 1, 'ESCA': 1}) -> None:
         r"""
         Initialize the visualization stage
         Args:
@@ -27,6 +28,8 @@ class CVisTree(IVisStage):
             info_file_esc(Path,str): infomration about the escape stage
         """
         self.strategy = strategy
+        self.strategies_stages = stage_strategies
+        self.abbreviations_filenames = self._setup_abbreviations()
         self.info_file_disp = info_file_disp
         self.info_file_esc = info_file_esc
         self.info_file_conv = info_file_conv
@@ -35,7 +38,23 @@ class CVisTree(IVisStage):
         self.image_scale_disp = 500
         self.image_scale_esc = 500
         self.image_scale_conv = 500
-        self.branchlength = 0.5
+        self.branchlength = 0.1
+        self.branchlength_disp = 0.1
+
+
+    def _setup_abbreviations(self) -> Dict[str, str]:
+        r"""
+        :return: Depending on the chosen algorithm the files are named differently. This method assigns the correct
+        abbreviations depending on the algorithms for the corresponding stages.
+        """
+        l_abb={}
+        if self.strategies_stages['ESC'] == 1:
+            l_abb['ESC'] = 'mf'
+        if self.strategies_stages['CONV'] == 1:
+            l_abb['CONV'] = 'mmf'
+        elif self.strategies_stages['CONV'] == 2:
+            l_abb['CONV'] = 'mfef'
+        return l_abb
 
     def set_image_scales(self, initial: float = 500, disp: float = 500, esc: float = 500, conv: float = 500):
         r"""
@@ -85,7 +104,6 @@ class CVisTree(IVisStage):
         df_conv = pd.read_csv(self.info_file_conv, sep=r'\s+')
         str = ''
         for index, key in enumerate(df_disp['DISPKEY']):
-
             str = str + '('
             current_esc_keys = df_esc[df_esc['DISPKEY'] == key]['ESCKEY'].to_numpy()
             current_esc_folders = df_esc[df_esc['DISPKEY'] == key]['folder'].to_numpy()
@@ -98,17 +116,19 @@ class CVisTree(IVisStage):
                 if esckey in esckeys_reescape:
                     continue
                 path_to_esc_folder = current_esc_folders[index2]
-                df_mf_calc = pd.read_csv(self.parent_directory / Path(path_to_esc_folder) / 'info_mf.dat', r'\s+')
+                l_abb = self.abbreviations_filenames['ESC']
+                df_mf_calc = pd.read_csv(self.parent_directory / Path(path_to_esc_folder) / f'info_{l_abb}.dat', r'\s+')
                 eig1 = abs(df_mf_calc['eig001'].to_numpy()[-1] * 1000)  # display in meV
                 df_conv_filtered = df_conv[df_conv['DISPKEY'] == key]
                 try:
                     sp_or_convex = df_conv_filtered[df_conv_filtered['ESCKEY'] == esckey]['sp_or_convex'].to_numpy()[0]
                     folder_search = df_conv_filtered[df_conv_filtered['ESCKEY'] == esckey]['folder'].to_numpy()[0]
-                    df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / 'info_mmf.dat', sep=r'\s+')
+                    l_abb = self.abbreviations_filenames['CONV']
+                    df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / f'info_{l_abb}.dat', sep=r'\s+')
                     eig1_conv = abs(df_mmf['eig001'].to_numpy()[-1] * 1000)  # in meV
                     if sp_or_convex == 'sp':
                         # str = str + f'({sp_or_convex}:{eig1_conv}){esckey}:{abs(eig1)},'
-                        str = str + f'({sp_or_convex}:{self.branchlength}){esckey}:{self.branchlength},'
+                        str = str + f'({sp_or_convex}:{self.branchlength}){esckey}:{self.branchlength_disp},'
                     else:
                         # look for re-escapes
                         current_reesc_keys = []
@@ -119,7 +139,8 @@ class CVisTree(IVisStage):
                                 current_reesc_keys_attempts.append(int(reesc_key[-2:]))
                         if not current_reesc_keys:
                             # list is empty no successful re-escape attempt for this key
-                            str = str + f'({sp_or_convex}:{eig1_conv}){esckey}:{abs(eig1)},'
+                            #str = str + f'({sp_or_convex}:{eig1_conv}){esckey}:{abs(eig1)},'
+                            str = str + f'({sp_or_convex}:{self.branchlength}){esckey}:{self.branchlength_disp},'
                         else:
                             # check ordering of keys
                             current_reesc_keys = [reesc_key for _, reesc_key in
@@ -135,18 +156,18 @@ class CVisTree(IVisStage):
                                 sp_or_convex = \
                                     df_conv_filtered[df_conv_filtered['ESCKEY'] == reesc_key][
                                         'sp_or_convex'].to_numpy()[0]
-                                reesc_str = reesc_str + f'{sp_or_convex}){reesc_key}:{1.0})'
+                                reesc_str = reesc_str + f'{sp_or_convex}::{self.branchlength}){reesc_key}:{self.branchlength})'
                             reesc_str = reesc_str[:-1]  # remove last bracket
                             # str = str + f'(({reesc_str}){sp_or_convex}:{eig1_conv}){esckey}:{abs(eig1)},'
-                            str = str + f'(({reesc_str}){sp_or_convex}:{self.branchlength}){esckey}:{self.branchlength},'
+                            str = str + f'(({reesc_str}){sp_or_convex}:{self.branchlength}){esckey}:{self.branchlength_disp},'
                 except IndexError:
                     # str = str + f'(NC:{0.0}){esckey}:{abs(eig1)},'
-                    str = str + f'(NC:{0.0}){esckey}:{self.branchlength},'
+                    str = str + f'(NC:{0.0}){esckey}:{self.branchlength_disp},'
             # remove last comma
             str = str[:-1]
             if not str[-1] == ',':
                 str = str + ')'
-            str = str + f'{key},'
+            str = str + f'{key}:{0.05},'
         return str[:-1]
 
     def _design_node_initial_state(self, tree: et.Tree) -> None:
@@ -156,8 +177,9 @@ class CVisTree(IVisStage):
         # maximum number of eigenvalues created by spinaker
         max_eval = 9
         root_node = tree.search_nodes(name='initial')[0]
-        img_face = et.ImgFace("SpinSTMi.png", width=self.image_scale_initial, height=self.image_scale_initial)
-        root_node.add_face(img_face, column=0, position='branch-right')
+        if (self.parent_directory / 'SpinSTMi.png').is_file():
+            img_face = et.ImgFace("SpinSTMi.png", width=self.image_scale_initial, height=self.image_scale_initial)
+            root_node.add_face(img_face, column=0, position='branch-right')
         rootnodestyle = et.NodeStyle()
         rootnodestyle['bgcolor'] = "Moccasin"
         root_node.set_style(rootnodestyle)
@@ -216,7 +238,9 @@ class CVisTree(IVisStage):
         escnodestyle['bgcolor'] = "Khaki"
         node.set_style(escnodestyle)
         # Test if an eigenvector file for the beginning of mmf exists
-        esc_evec0file = esc_spinfile.replace('spin_mf_end', 'evec_mmf_0')
+        l_abb_E = self.abbreviations_filenames['ESC']
+        l_abb_C = self.abbreviations_filenames['CONV']
+        esc_evec0file = esc_spinfile.replace(f'spin_{l_abb_E}_end', f'evec_{l_abb_C}_0')
         if Path(esc_evec0file).is_file():
             tf = et.TextFace('Lowest eigenmode', fsize=25)
             tf.inner_border.width = 1
@@ -227,15 +251,15 @@ class CVisTree(IVisStage):
             img_face.inner_border.type = 0
             node.add_face(img_face, column=1, position='branch-bottom')
 
-        path_to_mf_file = self.parent_directory / Path(current_esc_folder) / 'info_mf.dat'
+        path_to_mf_file = self.parent_directory / Path(current_esc_folder) / f'info_{l_abb_E}.dat'
         df_mf = pd.read_csv(path_to_mf_file, sep=r'\s+')
         eig1 = df_mf['eig001'].to_numpy()[-1]
         eig2 = df_mf['eig002'].to_numpy()[-1]
         node.add_feature('eig2', eig2)
         node.add_feature('eig1', eig1)
-        scientific_str = '{:.2e}'.format(eig1)
+        scientific_str = '{:.2e}'.format(float(eig1))
         tf1 = et.faces.TextFace(f"eig1:{scientific_str}", fsize=20)
-        scientific_str = '{:.2e}'.format(eig1)
+        scientific_str = '{:.2e}'.format(float(eig2))
         tf2 = et.faces.TextFace(f"eig2:{scientific_str}", fsize=20)
         node.add_face(tf1, column=0, position='branch-bottom')
         node.add_face(tf2, column=0, position='branch-bottom')
@@ -246,18 +270,19 @@ class CVisTree(IVisStage):
         """
         if not (df_conv['folder'].to_numpy().size == 0):
             folder_search = df_conv['folder'].to_numpy()[0]
-            df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / 'info_mmf.dat', sep=r'\s+')
+            l_abb_C = self.abbreviations_filenames['CONV']
+            df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / f'info_{l_abb_C}.dat', sep=r'\s+')
             eig1 = df_mmf['eig001'].to_numpy()[-1]
             eig2 = df_mmf['eig002'].to_numpy()[-1]
-            scientific_str = '{:.2e}'.format(eig1)
+            scientific_str = '{:.2e}'.format(float(eig1))
             tf1 = et.faces.TextFace(f"eig1:{scientific_str}", fsize=20)
-            scientific_str = '{:.2e}'.format(eig2)
+            scientific_str = '{:.2e}'.format(float(eig2))
             tf2 = et.faces.TextFace(f"eig2:{scientific_str}", fsize=20)
             node.add_face(tf1, column=0, position='branch-top')
             node.add_face(tf2, column=0, position='branch-top')
             energy_sp = df_mmf['energy'].to_numpy()[-1]
             steps_sp = df_mmf['steps'].to_numpy()[-1]
-            scientific_str = '{:.2e}'.format(energy_sp)
+            scientific_str = '{:.2e}'.format(float(energy_sp))
             tf1 = et.faces.TextFace(f"energy={scientific_str} eV", fsize=20)
             tf2 = et.faces.TextFace(f"steps={steps_sp}", fsize=20)
             node.add_face(tf1, column=0, position='branch-bottom')
@@ -303,7 +328,8 @@ class CVisTree(IVisStage):
             node.add_face(tf, column=1, position='branch-top')
             node.add_face(img_face, column=1, position='branch-top')
         # Test if an eigenvector file for the beginning of mmf exists
-        path_to_evec_file = self.parent_directory / Path(current_esc_spinfile).parent / 'evec_mmf_0.png'
+        l_abb_C = self.abbreviations_filenames['CONV']
+        path_to_evec_file = self.parent_directory / Path(current_esc_spinfile).parent / f'evec_{l_abb_C}_0.png'
         esc_evec0file = path_to_evec_file.as_posix()
         if Path(esc_evec0file).is_file():
             tf = et.TextFace('Lowest eigenmode', fsize=25)
@@ -321,9 +347,9 @@ class CVisTree(IVisStage):
         eig2 = df_mf['eig002'].to_numpy()[-1]
         node.add_feature('eig2', eig2)
         node.add_feature('eig1', eig1)
-        scientific_str = '{:.2e}'.format(eig1)
+        scientific_str = '{:.2e}'.format(float(eig1))
         tf1 = et.faces.TextFace(f"eig1:{scientific_str}", fsize=20)
-        scientific_str = '{:.2e}'.format(eig1)
+        scientific_str = '{:.2e}'.format(float(eig2))
         tf2 = et.faces.TextFace(f"eig2:{scientific_str}", fsize=20)
         node.add_face(tf1, column=0, position='branch-bottom')
         node.add_face(tf2, column=0, position='branch-bottom')
@@ -334,18 +360,19 @@ class CVisTree(IVisStage):
         """
         if not (df_conv['folder'].to_numpy().size == 0):
             folder_search = df_conv['folder'].to_numpy()[0]
-            df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / 'info_mmf.dat', sep=r'\s+')
+            l_abb_C = self.abbreviations_filenames['CONV']
+            df_mmf = pd.read_csv(self.parent_directory / Path(folder_search) / f'info_{l_abb_C}.dat', sep=r'\s+')
             eig1 = df_mmf['eig001'].to_numpy()[-1]
             eig2 = df_mmf['eig002'].to_numpy()[-1]
-            scientific_str = '{:.2e}'.format(eig1)
+            scientific_str = '{:.2e}'.format(float(eig1))
             tf1 = et.faces.TextFace(f"eig1:{scientific_str}", fsize=20)
-            scientific_str = '{:.2e}'.format(eig2)
+            scientific_str = '{:.2e}'.format(float(eig2))
             tf2 = et.faces.TextFace(f"eig2:{scientific_str}", fsize=20)
             node.add_face(tf1, column=0, position='branch-top')
             node.add_face(tf2, column=0, position='branch-top')
             energy_sp = df_mmf['energy'].to_numpy()[-1]
             steps_sp = df_mmf['steps'].to_numpy()[-1]
-            scientific_str = '{:.2e}'.format(energy_sp)
+            scientific_str = '{:.2e}'.format(float(energy_sp))
             tf1 = et.faces.TextFace(f"energy={scientific_str} eV", fsize=20)
             tf2 = et.faces.TextFace(f"steps={steps_sp}", fsize=20)
             node.add_face(tf1, column=0, position='branch-bottom')
@@ -394,12 +421,12 @@ class CVisTree(IVisStage):
         df_disp = pd.read_csv(self.info_file_disp, sep=r'\s+')
         df_esc = pd.read_csv(self.info_file_esc, sep=r'\s+')
         df_conv = pd.read_csv(self.info_file_conv, sep=r'\s+')
-        t = et.Tree(f'({self._create_newick_string()})initial:0.0;', format=1)
-        self._design_node_initial_state(tree=t)
+        self.tree = et.Tree(f'({self._create_newick_string()})initial:0.0;', format=1)
+        self._design_node_initial_state(tree=self.tree)
         # Add features/ faces to tree
         for index, key in enumerate(df_disp['DISPKEY']):
             # This should be unique get the escape nodes
-            key_node = t.search_nodes(name=key)[0]
+            key_node = self.tree.search_nodes(name=key)[0]
             self._design_node_displaced_state(node=key_node, df_disp=df_disp, index=index, key=key)
             escape_nodes = key_node.get_children()
             # get sub data frame
@@ -431,17 +458,29 @@ class CVisTree(IVisStage):
                         except IndexError:
                             nodes_at_current_depth = False
                             print('reached leaf')
-        ts = et.TreeStyle()
+        self.ts = et.TreeStyle()
         # Do not add leaf names automatically
-        ts.show_leaf_name = False
-        ts.mode = 'c'
-        ts.show_scale = False
-        ts.show_branch_length = False
-        ts.root_opening_factor = 0.0
-        ts.arc_span = 360
+        self.ts.show_leaf_name = False
+        self.ts.mode = 'c'
+        self.ts.show_scale = False
+        self.ts.show_branch_length = False
+        self.ts.root_opening_factor = 0.0
+        self.ts.arc_span = 360
         # Use my custom layout
-        ts.layout_fn = my_layout
-        t.show(tree_style=ts)
+        self.ts.layout_fn = my_layout
+
+    def show_ete_tree(self):
+        r"""
+        Shows ete tree
+        """
+        self.tree.show(tree_style=self.ts)
+
+    def render_ete_tree(self, filename:str = 'tree_ete.pdf'):
+        r"""
+        Args:
+            filename: name and format of the file
+        """
+        self.tree.render(filename,tree_style=self.ts)
 
     def _create_tree_treelib(self):
         r"""
